@@ -34,15 +34,15 @@ enum
 struct _GlEventViewDetail
 {
     /*< private >*/
-    GtkBin parent_instance;
+    GtkPopover parent_instance;
 };
 
 typedef struct
 {
-    GlJournalEntry *entry;
+    GlRowEntry *entry;
     GlUtilClockFormat clock_format;
     GtkWidget *grid;
-    GtkWidget *comm_image;
+    GtkWidget *comm_field_label;
     GtkWidget *comm_label;
     GtkWidget *time_label;
     GtkWidget *message_label;
@@ -62,7 +62,7 @@ typedef struct
     GtkWidget *detailed_message_label;
 } GlEventViewDetailPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (GlEventViewDetail, gl_event_view_detail, GTK_TYPE_BIN)
+G_DEFINE_TYPE_WITH_PRIVATE (GlEventViewDetail, gl_event_view_detail, GTK_TYPE_POPOVER)
 
 static GParamSpec *obj_properties[N_PROPERTIES] = { NULL, };
 
@@ -71,6 +71,7 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
 {
     GlEventViewDetailPrivate *priv;
     GlJournalEntry *entry;
+    GlRowEntry *row_entry;
     gchar *str;
     gchar *str_field;
     gchar *str_message;
@@ -79,7 +80,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
 
     priv = gl_event_view_detail_get_instance_private (detail);
 
-    entry = priv->entry;
+    row_entry = priv->entry;
+    entry = gl_row_entry_get_journal_entry (row_entry);
 
     /* Force LTR direction also for RTL languages */
     gtk_widget_set_direction (priv->grid, GTK_TEXT_DIR_LTR);
@@ -95,31 +97,9 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
 
     if (gl_journal_entry_get_command_line (entry))
     {
-        /* Command-line, look for a desktop file. */
-        GDesktopAppInfo *desktop;
-
-        /* TODO: Use g_desktop_app_info_search? */
-        str = g_strconcat (gl_journal_entry_get_command_line (entry), ".desktop", NULL);
-        desktop = g_desktop_app_info_new (str);
-        g_free (str);
-
-        if (desktop)
-        {
-            GIcon *icon;
-
-            icon = g_app_info_get_icon (G_APP_INFO (desktop));
-            gtk_image_set_from_gicon (GTK_IMAGE (priv->comm_image),
-                                      icon, GTK_ICON_SIZE_DIALOG);
-            gtk_widget_show (priv->comm_image);
-            gtk_label_set_text (GTK_LABEL (priv->comm_label),
-                                g_app_info_get_name (G_APP_INFO (desktop)));
-
-            g_object_unref (desktop);
-        }
-        else
-        {
-            gtk_label_set_text (GTK_LABEL (priv->comm_label), gl_journal_entry_get_command_line (entry));
-        }
+        gtk_label_set_text (GTK_LABEL (priv->comm_label), gl_journal_entry_get_command_line (entry));
+        gtk_widget_show (priv->comm_field_label);
+        gtk_widget_show (priv->comm_label);
     }
 
     now = g_date_time_new_now_local ();
@@ -427,8 +407,8 @@ gl_event_view_detail_class_init (GlEventViewDetailClass *klass)
                                                            G_PARAM_STATIC_STRINGS);
 
     obj_properties[PROP_ENTRY] = g_param_spec_object ("entry", "Entry",
-                                                      "Journal entry for this detailed view",
-                                                      GL_TYPE_JOURNAL_ENTRY,
+                                                      "Row entry for this detailed view",
+                                                      GL_TYPE_ROW_ENTRY,
                                                       G_PARAM_READWRITE |
                                                       G_PARAM_CONSTRUCT_ONLY |
                                                       G_PARAM_STATIC_STRINGS);
@@ -441,7 +421,7 @@ gl_event_view_detail_class_init (GlEventViewDetailClass *klass)
     gtk_widget_class_bind_template_child_private (widget_class, GlEventViewDetail,
                                                   grid);
     gtk_widget_class_bind_template_child_private (widget_class, GlEventViewDetail,
-                                                  comm_image);
+                                                  comm_field_label);
     gtk_widget_class_bind_template_child_private (widget_class, GlEventViewDetail,
                                                   comm_label);
     gtk_widget_class_bind_template_child_private (widget_class, GlEventViewDetail,
@@ -485,7 +465,7 @@ gl_event_view_detail_init (GlEventViewDetail *detail)
 }
 
 GtkWidget *
-gl_event_view_detail_new (GlJournalEntry *entry,
+gl_event_view_detail_new (GlRowEntry *entry,
                           GlUtilClockFormat clock_format)
 {
     return g_object_new (GL_TYPE_EVENT_VIEW_DETAIL, "entry", entry,
