@@ -25,7 +25,6 @@
 #include "gl-categorylist.h"
 #include "gl-enums.h"
 #include "gl-eventtoolbar.h"
-#include "gl-eventview.h"
 #include "gl-eventviewdetail.h"
 #include "gl-eventviewrow.h"
 #include "gl-journal-model.h"
@@ -41,7 +40,7 @@ struct _GlEventViewList
 typedef struct
 {
     GlJournalModel *journal_model;
-    GlJournalEntry *entry;
+    GlRowEntry *entry;
     GlUtilClockFormat clock_format;
     GtkListBox *entries_box;
     GtkSizeGroup *category_sizegroup;
@@ -135,6 +134,7 @@ listbox_update_header_func (GtkListBoxRow *row,
                             gpointer user_data)
 {
     GtkWidget *current;
+    GlRowEntry *row_entry;
 
     if (before == NULL)
     {
@@ -144,11 +144,16 @@ listbox_update_header_func (GtkListBoxRow *row,
 
     current = gtk_list_box_row_get_header (row);
 
-    if (current == NULL)
+    row_entry = gl_event_view_row_get_entry (GL_EVENT_VIEW_ROW (row));
+
+    if (! (gl_row_entry_get_row_type (row_entry) == GL_ROW_ENTRY_TYPE_COMPRESSED))
     {
-        current = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-        gtk_widget_show (current);
-        gtk_list_box_row_set_header (row, current);
+        if (current == NULL)
+        {
+            current = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+            gtk_widget_show (current);
+            gtk_list_box_row_set_header (row, current);
+        }
     }
 }
 
@@ -160,34 +165,59 @@ on_listbox_row_activated (GtkListBox *listbox,
                           GlEventViewList *view)
 {
     GlEventViewListPrivate *priv;
-    GtkWidget *toplevel;
 
     priv = gl_event_view_list_get_instance_private (view);
     priv->entry = gl_event_view_row_get_entry (GL_EVENT_VIEW_ROW (row));
 
-    toplevel = gtk_widget_get_toplevel (GTK_WIDGET (view));
-
-    if (gtk_widget_is_toplevel (toplevel))
+    if (gl_row_entry_get_row_type (priv->entry) == GL_ROW_ENTRY_TYPE_HEADER)
     {
-        GAction *mode;
-        GEnumClass *eclass;
-        GEnumValue *evalue;
+        guint compressed_entries;
+        gint header_row_index;
+        gint index;
 
-        mode = g_action_map_lookup_action (G_ACTION_MAP (toplevel), "view-mode");
-        eclass = g_type_class_ref (GL_TYPE_EVENT_VIEW_MODE);
-        evalue = g_enum_get_value (eclass, GL_EVENT_VIEW_MODE_DETAIL);
+        compressed_entries = gl_row_entry_get_compressed_entries (priv->entry);
+        header_row_index = gtk_list_box_row_get_index (row);
 
-        g_action_activate (mode, g_variant_new_string (evalue->value_nick));
+        for (index = header_row_index + 1; compressed_entries != 0; index++)
+        {
+            GtkListBoxRow *compressed_row;
+            GtkStyleContext *context;
 
-        g_type_class_unref (eclass);
+            compressed_row = gtk_list_box_get_row_at_index (GTK_LIST_BOX (priv->entries_box),
+                                                            index);
+
+            context = gtk_widget_get_style_context (GTK_WIDGET (compressed_row));
+            gtk_style_context_add_class (context, "compressed-row");
+
+            context = gtk_widget_get_style_context (GTK_WIDGET (row));
+
+            /* Toggle the visibility */
+            if (gtk_widget_get_visible (GTK_WIDGET (compressed_row)))
+            {
+                gtk_widget_hide (GTK_WIDGET (compressed_row));
+                gtk_style_context_remove_class (context, "compressed-row-header");
+            }
+            else
+            {
+                gtk_widget_show (GTK_WIDGET (compressed_row));
+                gtk_style_context_add_class (context, "compressed-row-header");
+            }
+
+            compressed_entries--;
+        }
     }
     else
     {
-        g_debug ("Widget not in toplevel window, not switching toolbar mode");
+        GtkWidget *event_detail_popover;
+
+        event_detail_popover = gl_event_view_detail_new (priv->entry, priv->clock_format);
+        gtk_popover_set_relative_to (GTK_POPOVER (event_detail_popover), GTK_WIDGET (row));
+
+        gtk_widget_show (event_detail_popover);
     }
 }
 
-GlJournalEntry *
+GlRowEntry *
 gl_event_view_list_get_detail_entry (GlEventViewList *view)
 {
     GlEventViewListPrivate *priv;
@@ -605,10 +635,16 @@ create_query_object (GlEventViewList *view)
     GlEventViewListPrivate *priv;
     GlQuery *query;
     GlCategoryList *list;
+    GSettings *settings;
+    gint sort_order;
 
     priv = gl_event_view_list_get_instance_private (view);
     list = GL_CATEGORY_LIST (priv->categories);
 
+    /* Get the sorting order from GSettings key */
+    settings = g_settings_new (SETTINGS_SCHEMA);
+    sort_order = g_settings_get_enum (settings, SORT_ORDER);
+
     /* Create new query object */
     query = gl_query_new ();
 
@@ -621,6 +657,10 @@ create_query_object (GlEventViewList *view)
 
     gl_query_set_search_type (query, priv->search_type);
 
+    gl_query_set_sort_order (query, sort_order);
+
+    g_object_unref (settings);
+
     return query;
 }
 
@@ -631,8 +671,6 @@ on_notify_category (GlCategoryList *list,
 {
     GlEventViewList *view;
     GlEventViewListPrivate *priv;
-    GSettings *settings;
-    gint sort_order;
     GlQuery *query;
 
     view = GL_EVENT_VIEW_LIST (user_data);
@@ -643,11 +681,6 @@ on_notify_category (GlCategoryList *list,
 
     /* Set the created query on the journal model */
     gl_journal_model_take_query (priv->journal_model, query);
-
-    settings = g_settings_new (SETTINGS_SCHEMA);
-    sort_order = g_settings_get_enum (settings, SORT_ORDER);
-    g_object_unref (settings);
-    gl_event_view_list_set_sort_order (view, sort_order);
 }
 
 void
@@ -668,89 +701,24 @@ gl_event_view_list_view_boot (GlEventViewList *view, const gchar *match)
     gl_search_popover_set_journal_timestamp_range_current_boot (popover);
 }
 
-static gint
-gl_event_view_sort_by_ascending_time (GtkListBoxRow *row1,
-                                      GtkListBoxRow *row2)
-{
-    GlJournalEntry *entry1;
-    GlJournalEntry *entry2;
-    guint64 time1;
-    guint64 time2;
-
-    entry1 = gl_event_view_row_get_entry (GL_EVENT_VIEW_ROW (row1));
-    entry2 = gl_event_view_row_get_entry (GL_EVENT_VIEW_ROW (row2));
-    time1 = gl_journal_entry_get_timestamp (entry1);
-    time2 = gl_journal_entry_get_timestamp (entry2);
-
-    if (time1 > time2)
-    {
-        return 1;
-    }
-    else if (time1 < time2)
-    {
-        return -1;
-    }
-    else
-    {
-        return 0;
-    }
-}
-
-static gint
-gl_event_view_sort_by_descending_time (GtkListBoxRow *row1,
-                                       GtkListBoxRow *row2)
-{
-    GlJournalEntry *entry1;
-    GlJournalEntry *entry2;
-    guint64 time1;
-    guint64 time2;
-
-    entry1 = gl_event_view_row_get_entry (GL_EVENT_VIEW_ROW (row1));
-    entry2 = gl_event_view_row_get_entry (GL_EVENT_VIEW_ROW (row2));
-    time1 = gl_journal_entry_get_timestamp (entry1);
-    time2 = gl_journal_entry_get_timestamp (entry2);
-
-    if (time1 > time2)
-    {
-        return -1;
-    }
-    else if (time1 < time2)
-    {
-        return 1;
-    }
-    else
-    {
-        return 0;
-    }
-}
-
 void
 gl_event_view_list_set_sort_order (GlEventViewList *view,
                                    GlSortOrder sort_order)
 {
     GlEventViewListPrivate *priv;
+    GlQuery *query;
 
     g_return_if_fail (GL_EVENT_VIEW_LIST (view));
 
     priv = gl_event_view_list_get_instance_private (view);
 
-    switch (sort_order)
-    {
-        case GL_SORT_ORDER_ASCENDING_TIME:
-            gtk_list_box_set_sort_func (GTK_LIST_BOX (priv->entries_box),
-                                        (GtkListBoxSortFunc) gl_event_view_sort_by_ascending_time,
-                                        NULL, NULL);
-            break;
-        case GL_SORT_ORDER_DESCENDING_TIME:
-            gtk_list_box_set_sort_func (GTK_LIST_BOX (priv->entries_box),
-                                        (GtkListBoxSortFunc) gl_event_view_sort_by_descending_time,
-                                        NULL, NULL);
-            break;
-        default:
-            g_assert_not_reached ();
-            break;
-    }
+    /* Create the query object */
+    query = create_query_object (view);
 
+    /* The sort order is taken from the GSettings key irrespective
+     * of current model sort order and the created query is passed
+     * on to model */
+    gl_journal_model_take_query (priv->journal_model, query);
 }
 
 static void
